// Esempio di uso bottoni e memorizzazione dati in istanti successivi
// Quando viene premuto il pulsante 1 il LED rosso si accende e nella
// variabile VarMem1 viene salvato il valore letto in quel momento 
// dell'ingresso analogico A0

// Quando viene premuto il pulsante 2 il LED verde si accende e nella
// variabile VarMem2 viene salvato il valore letto in quel momento 
// dell'ingresso analogico A0

// A questo punto (entrambi i LED accesi), si possono effettuare calcoli
// utilizzando i due valori memorizzati. Esempio: su A0 si utilizza un unico 
// sensore LM35 e i valori letti in A0 vengono convertiti in temperature  

// Collegare i terminali del bottone 1 (rosso): uno a GND e l'altro al pin buttonPin1 di Arduino
const int buttonPin1 = 2;    

// Collegare il led 1 (rosso): piedino piu' corto a GND, piedino piu' lungo al pin ledPin1 di Arduino
// ricordandosi di mettere in serie una resistenza da 500-1000 Ohm
const int ledPin1 =  12;     

// Collegare i terminali del bottone 2 (verde): uno a GND e l'altro al pin buttonPin2 di Arduino
const int buttonPin2 = 3;    

// Collegare il led 2 (verde): piedino piu' corto a GND, piedino piu' lungo al pin ledPin2 di Arduino
// ricordandosi di mettere in serie una resistenza da 500-1000 Ohm
const int ledPin2 =  13;     

// Variabili in cui verranno memorizzati i due valori letti negli istanti successivi
int VarMem1 = 0; 
int VarMem2 = 0; 

// Inizialmente i LED sono spenti. Lo stato dei LED indica anche se e' stato memorizzato un valore ai
// rispettivi istanti 1 e 2
bool Led1ON = false;
bool Led2ON = false;

int buttonState1 = 0;         // variable for reading the pushbutton status
int buttonState2 = 0;         // variable for reading the pushbutton status


void setup() {

// Inizializza monitor seriale
Serial.begin(9600);

// Imposta i pin per la lettura pulsanti, abilitando la resistenza pullup a +5V interna (vedi dispense...)
pinMode(buttonPin1, INPUT_PULLUP);
pinMode(buttonPin2, INPUT_PULLUP);  

// Imposta i pin per i LED come uscite
pinMode(ledPin1, OUTPUT);
pinMode(ledPin2, OUTPUT);
}


void loop() {

// Lettura dei pulsanti. Nota: normalmente (non premuto) lo stato e' HIGH (PULLUP...)
// ovvero ragioniamo a logica inversa: quando il pulsante e' premuto leggo "LOW" sul buttonPin1/2
buttonState1 = digitalRead(buttonPin1);
buttonState2 = digitalRead(buttonPin2);

// Pigiato solo pulsante 1
if (buttonState1 == LOW && buttonState2 == HIGH) {
    Led1ON = true;
    digitalWrite(ledPin1, HIGH);
    VarMem1 = analogRead(A0);
  }

// Pigiato solo pulsante 2
if (buttonState1 == HIGH && buttonState2 == LOW) {
    Led2ON = true;
    digitalWrite(ledPin2, HIGH);
    VarMem2 = analogRead(A0);
  }

// Pigiati entrambi: cancella tutti i valori memorizzati
if (buttonState1 == LOW && buttonState2 == LOW) {
    Led1ON = false;
    Led2ON = false;
    digitalWrite(ledPin1, LOW);
    digitalWrite(ledPin2, LOW);
    VarMem1 = 0;
    VarMem2 = 0;
    delay(1000); // i pulsanti non vengono rilasciati esattamente insieme...
  }


  Serial.print("Valore 1 = " );
  Serial.print(VarMem1);
  Serial.print("    Valore 2 = " );
  Serial.println(VarMem2);


delay(100);
}
